=====================
Compose-X -- Common
=====================


.. image:: https://img.shields.io/pypi/v/compose_x_common.svg
        :target: https://pypi.python.org/pypi/compose_x_common

.. image:: https://readthedocs.org/projects/compose-x-commons-lib/badge/?version=latest
        :target: https://compose-x-commons-lib.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Standalone library of reusable functions"


* Free software: MPL-2.0
* Documentation: https://compose-x-common.readthedocs.io.
